@@ -63,7 +63,7 @@ class Connect:
             connection.close()
         elif self.dbengine=="PSQL":
             try:
-                connection=psycopg2.connect(host=self.items['server'],dbname=self.items['database'],user=self.items['username'],password=self.items['password'])
+                connection=psycopg2.connect(host=self.items['server'],database=self.items['database'],user=self.items['username'],password=self.items['password'])
      
                 # prepare a cursor object using cursor() method
                 cursor =connection.cursor()
@@ -73,7 +73,8 @@ class Connect:
                 # Fetch all the rows in a list of lists.
                 results = cursor.fetchall()
                 return results
-            except: 
+            except psycopg2.Error,e:   
+                print "Error %s" % (e)
                 return None
                 connection.close()
                 
@@ -89,7 +90,8 @@ class Connect:
                 # Fetch all the rows in a list of lists.
                 results = cursor.fetchall()
                 return results
-            except: 
+            except psycopg2.Error,e:           
+                print "Error %d: %s" % (e.args[0], e.args[1])
                 return None
             connection.close()
             
@@ -125,7 +127,7 @@ class Connect:
         elif self.dbengine=="PSQL":
             try:
                 # Open database connection
-                connection=psycopg2.connect(host=self.items['server'],dbname=self.items['database'],user=self.items['username'],password=self.items['password'])
+                connection=psycopg2.connect(host=self.items['server'],database=self.items['database'],user=self.items['username'],password=self.items['password'])
                 # prepare a cursor object using cursor() method
                 cursor =connection.cursor()
             
@@ -134,12 +136,9 @@ class Connect:
                 # Commit your changes in the database
                 connection.commit()
                 return True
-            except:            
-                MySQLError
-                #Roll Back incase of failure
-                #connection.roleback()
-                print "Error has occured"
-                return False
+            except psycopg2.Error,e:           
+                print "Error %s" % (e)
+                return None
             connection.close()
             
         elif self.dbengine=="Oracle":
@@ -197,7 +196,8 @@ class Connect:
                 # Fetch a single row using fetchone() method.
                 result = cursor.fetchone()
                 return result
-            except:         
+            except psycopg2.Error,e:           
+                print "Error %s" % (e)        
                           
                 return None
         
