@@ -9,6 +9,7 @@ Created on Feb 2, 2012
 
 from Connect import Connect
 import MySQLdb
+import psycopg2
 class ConnectOperations:
     """
     This Class is the base CRUD class for all database tables models.
@@ -47,7 +48,11 @@ class ConnectOperations:
             result= self.con.nonequery(sqlstr)
             print "Record Inserted"
             return result
-        except:
+        except MySQLdb.Error or psycopg2.Error, e:
+            if self.con.dbengine=="MySQL":
+                print e.message
+            elif self.con.dbengine=="PSQL":
+                print e.message
             print "may be make sure your dictionary values corresponds to the table in your database"
             
             return
